Index: trunk/kernel/devices/dev_txt.h
===================================================================
--- trunk/kernel/devices/dev_txt.h	(revision 1)
+++ trunk/kernel/devices/dev_txt.h	(revision 3)
@@ -30,5 +30,5 @@
 /****  Forward declarations  ****/
 
-struct device_s ;
+struct chdev_s ;
 
 /******************************************************************************************
@@ -79,21 +79,20 @@
 
 /******************************************************************************************
  * This function completes the TXT device descriptor initialisation,
  * namely the link with the implementation specific driver.
- * The func, impl, channel, is_rxt, base, and size fields must be previously initialised.
+ * The func, impl, channel, is_rxt, base fields have been previously initialised.
  * It calls the specific driver initialisation function, to initialise the hardware
  * device and the driver specific data structures when required.
- * It creates the associated server thread.
- * It can be executed in another cluster than cluster containing the device descriptor
- * or the hardware device itself.
+ * It creates the associated server thread and allocates a WTI from local ICU.
+ * It must de executed by a local thread.
  ******************************************************************************************
  * @ xp_dev     : extended pointer on TXT device descriptor.
  *****************************************************************************************/
-void dev_txt_init( xptr_t xp_dev );
+void dev_txt_init( struct chdev_s * chdev );
 
 /******************************************************************************************
  * This blocking function read a single character from the terminal identified
  * by the "channel" argument. The corresponding request is actually registered in the
  * device pending requests queue, and the calling thread is descheduled, blocked until
  * transfer completion.
  * It must be called in the client cluster.
@@ -109,5 +108,5 @@
  * This blocking function writes a character string on the terminal identified
  * by the "channel" argument. The corresponding request is actually registered in the
  * device pending requests queue, and the calling thread is descheduled, blocked until
  * transfer completion.
  * It must be called in the client cluster.
@@ -123,5 +122,5 @@
 
  /***************************************************************************************
- * This low-level blocking function is used by the kernel to display one character on a 
+ * This low-level blocking function is used by the kernel to display one string on a 
  * given TXT channel without descheduling the calling thread,  without registering it 
  * in the TXT device waiting queue, and without using the TXT irq. 
@@ -136,21 +135,4 @@
                             uint32_t   count );
 
-/******************************************************************************************
- * This function is executed by the server thread associated to the TXT device descriptor.
- * This thread is created and lauched by the dev_txt_init() function, and is used
- * by the TXT_READ and TXT_WRITE operation types. It executes an infinite loop to handle
- * sequencially all commands registered by the client threads in the device waiting queue.
- *  
- * The driver CMD function is blocking, and returns only when the command is completed.
- * can use a busy waiting policy, or block the server thread on the THREAD_BLOCKED_IO_ISR
- * condition and deschedule, using the ISR to reactivate the server thread.
- *
- * When the waiting queue is empty, the server thread blocks on the THREAD_BLOCKED_IO_CMD
- * condition and deschedule. It is re-activated by a client thread registering a command.
- ******************************************************************************************
- * @ dev     : local pointer on device descriptor.
- *****************************************************************************************/
-void dev_txt_server( struct device_s * dev );
-
 
 #endif	/* _DEV_TXT_H_ */
@@ -79,21 +79,20 @@
 
 /******************************************************************************************
- * This function completes the TXT device descriptor initialisation,
+ * This function completes the TXT chdev descriptor initialisation,
  * namely the link with the implementation specific driver.
@@ -79,21 +79,20 @@
  ******************************************************************************************
- * @ xp_dev     : extended pointer on TXT device descriptor.
+ * @ chdev     : local pointer on TXT device descriptor.
  *****************************************************************************************/
@@ -79,21 +79,20 @@
  * This blocking function read a single character from the terminal identified
  * by the "channel" argument. The corresponding request is actually registered in the
- * device pending requests queue, and the calling thread is descheduled, blocked until
+ * chdev requests queue, and the calling thread is descheduled, blocked until
  * transfer completion.
  * It must be called in the client cluster.
@@ -109,5 +108,5 @@
  * This blocking function writes a character string on the terminal identified
  * by the "channel" argument. The corresponding request is actually registered in the
- * device pending requests queue, and the calling thread is descheduled, blocked until
+ * chdev requests queue, and the calling thread is descheduled, blocked until
  * transfer completion.
  * It must be called in the client cluster.
